pub struct StringSchema { /* private fields */ }Implementations
Sourceimpl StringSchema
impl StringSchema
pub fn new() -> Self
pub fn min(self, min: usize) -> Self
pub fn max(self, max: usize) -> Self
pub fn length(self, len: usize) -> Self
pub fn starts_with(self, val: &str) -> Self
pub fn ends_with(self, val: &str) -> Self
pub fn includes(self, val: &str) -> Self
Sourcepub fn regex(self, pattern: &str) -> Self
pub fn regex(self, pattern: &str) -> Self
Sets a regex pattern for validation.
Panics
Panics if the pattern is not a valid regex. Use try_regex() for fallible version.
Sourcepub fn try_regex(self, pattern: &str) -> Result<Self, Error>
pub fn try_regex(self, pattern: &str) -> Result<Self, Error>
Sets a regex pattern for validation, returning an error if the pattern is invalid.
pub fn email(self) -> Self
pub fn url(self) -> Self